@@ -71,7 +71,8 @@ procfun = processSocket, secure = FALSE, local = !secure)
 				pos <-  match("SciViews:TempEnv", search())
 				if (is.na(pos)) {  # Must create it
 					`SciViews:TempEnv` <- list()
-					attach(`SciViews:TempEnv`, pos = length(search()) - 1)
+					Attach <- function (...) get("attach", mode = "function")(...)
+					Attach(`SciViews:TempEnv`, pos = length(search()) - 1)
 					rm(`SciViews:TempEnv`)
 					pos <- match("SciViews:TempEnv", search())
 				}
